@@ -42,10 +42,6 @@ class FileSystem(ABC):
     def find(self, path: str, filename: str):
         pass
 
-    @abstractmethod
-    def get_file(self, source: str, destination: str):
-        pass
-
     @abstractmethod
     def read_bytes(self, filename: str):
         pass
@@ -61,6 +57,41 @@ class FileSystem(ABC):
     def grep(self, iterable: iter, regex: str) -> list:
         return [obj for obj in iterable if re.match(rf'{regex}', obj)]
 
+    def cp(self, source, destination):
+        """
+        Copy a file from:
+            1) Minio to local e.g cp("s3://bucket/folder/file.txt", "./file.txt")
+            2) local to Minio e.g cp("./file.txt", "s3://bucket/folder/file.txt")
+            3) local to local e.g cp("./file.txt", "./newfile/txt")
+            4) Minio to minio e.g cp("s3://bucket/folder/file.txt", "s3://bucket/folder/newfile.txt")
+
+        Prefix minio paths with a s3://
+        """
+        source_type = 'local'
+        destination_type = 'local'
+        if 's3://' in source:
+            source_type = 'remote'
+            source_path = source.split('s3://')[1]
+            source_bucket, source_filename = self._process_path(source_path)
+        if 's3://' in destination:
+            destination_type = 'remote'
+            destination_path = destination.split('s3://')[1]
+            destination_bucket, destination_filename = self._process_path(destination_path)
+
+        logger.info(f"Copying from {source_type}: {source} to {destination_type}: {destination}")
+
+        if source_type == 'remote' and destination_type == 'local':
+            self.__client__.fget_object(source_bucket, object_name=source_filename, file_path=destination)
+
+        if source_type == 'local' and destination_type == 'remote':
+            self.__client__.fput_object(destination_bucket, object_name=destination_filename, file_path=source)
+
+        if source_type == 'local' and destination_type == 'local':
+            shutil.copyfile(source, destination)
+
+        if source_type == 'remote' and destination_type == 'remote':
+            self.__client__.copy_object(source_bucket, destination_filename, source_filename)
+
 
 class MinioFS(FileSystem):
     def __init__(self, hostname, access_key=None, secret_key=None, secure=True):
@@ -135,12 +166,6 @@ class MinioFS(FileSystem):
 
         return filepaths
 
-    def get_file(self, source, destination):
-        bucket, filename = self._process_path(source)
-        self.__client__.fget_object(bucket, object_name=filename, file_path=destination)
-        logger.info("Success")
-        return
-
     def read_bytes(self, filename):
         data = self._stream_file(filename)
         return b''.join(data)
@@ -269,18 +294,6 @@ class LocalFS(FileSystem):
                 filepaths.append(os.path.join(root, filename))
         return filepaths
 
-    def get_file(self, source, destination):
-        """
-        Effectively the same as just copying a file from a source to destination.
-        :param source: Path to the source file
-        :param destination: Path to where to copy the file to
-        :return:
-        """
-        logger.info(f"Getting file from {source} to {destination}")
-        shutil.copy2(source, destination)
-        logger.info(f"Success.")
-        return
-
     def read_bytes(self, filename):
         """
         Read bytes of a file.
