@@ -81,13 +81,6 @@ def test_minio_find(MinioFileSystem):
     assert output == ["test/filename.csv"]
 
 
-def test_minio_get_file(MinioFileSystem):
-    MinioFileSystem.get_file("bucket/source.txt", "destination/file.txt")
-    MinioFileSystem.__client__.fget_object.assert_called_once_with('bucket',
-                                                                   object_name="source.txt",
-                                                                   file_path='destination/file.txt')
-
-
 @mock.patch('miniMinio.FileSystem.MinioFS._stream_file')
 def test_minio_read_bytes(stream_file, MinioFileSystem):
     stream_file.return_value = [b'some', b'data', b'to', b'test']
@@ -183,13 +176,41 @@ def test_local_find(walk, LocalFileSystem):
     assert paths == ["./file.txt"]
 
 
-@mock.patch('miniMinio.FileSystem.shutil.copy2')
-def test_local_get_file(copy, LocalFileSystem):
-    LocalFileSystem.get_file('source/file.txt', 'destination/file.txt')
-    copy.assert_called_once_with('source/file.txt', 'destination/file.txt')
-
-
 @mock.patch('os.remove')
 def test_local_rm(remove, LocalFileSystem):
     LocalFileSystem.rm(['./file1.txt', './file2.txt'])
     assert remove.call_count == 2
+
+
+@pytest.mark.parametrize('destination', ['s3://bucket/text_destination.txt', './text_destination.txt'])
+@pytest.mark.parametrize('source', ['s3://bucket/text_source.txt', './text_source.txt'])
+@mock.patch('miniMinio.FileSystem.shutil.copyfile')
+def test_cp(copyfile, MinioFileSystem, destination, source):
+    MinioFileSystem.cp(source=source, destination=destination)
+    if source == 's3://text_source.txt' and destination == './text_destination.txt':
+        MinioFileSystem.__client.__fget_object.assert_called_once_with('bucket',
+                                                                       object_name='bucket/text_source.txt',
+                                                                       file_path='./text_destination.txt')
+        MinioFileSystem.__client__.fput_object.assert_not_called()
+        MinioFileSystem.__cluent__.copy_object.assert_not_called()
+        copyfile.assert_not_called()
+
+    if source == './text_source.txt' and destination == 's3://bucket/text_destination.txt':
+        MinioFileSystem.__client__.fput_object.assert_called_once_with('bucket',
+                                                                       object_name='text_destination.txt',
+                                                                       file_path='./text_source.txt')
+        MinioFileSystem.__client__.fget_object.assert_not_called()
+        MinioFileSystem.__client__.copy_object.assert_not_called()
+        copyfile.assert_not_called()
+
+    if source == './text_source.txt' and destination == './text_destination.txt':
+        copyfile.assert_called_once_with(source, destination)
+        MinioFileSystem.__client__.fget_object.assert_not_called()
+        MinioFileSystem.__client__.copy_object.assert_not_called()
+        MinioFileSystem.__client__.fput_object.assert_not_called()
+
+    if source == 's3://bucket/text_source.txt' and destination == 's3://bucket/text_destination.txt':
+        MinioFileSystem.__client__.copy_object.assert_called_once_with('bucket', 'text_destination.txt', 'text_source.txt')
+        MinioFileSystem.__client__.fget_object.assert_not_called()
+        copyfile.assert_not_called()
+        MinioFileSystem.__client__.fput_object.assert_not_called()
\ No newline at end of file
